Learn R Programming

BayesReversePLLH (version 1.5)

GetALLHazLogSlope: Computes the posterior distribution of hazard value for a vector x for the Piecewise Linear Log Hazard model (PLLH)

Description

Computes the posterior distribution of hazard value for a vector x for the Piecewise Linear Log Hazard model (PLLH)

Usage

GetALLHazLogSlope(x, G1)

Value

Matrix containing the posterior distribution of hazard values h(x)

Arguments

x

Vector of times to compute the posterior mean hazard function

G1

List of posterior samples from the BayesPiecewiseLinearLogHazard function.