Learn R Programming

BayesReversePLLH (version 1.5)

GetALLHazPiece: Computes the posterior hazard values for a vector x for the Piecewise Exponential Hazard model (PEH)

Description

Computes the posterior hazard values for a vector x for the Piecewise Exponential Hazard model (PEH)

Usage

GetALLHazPiece(x, G1)

Value

Matrix containing the posterior distribution of hazard values h(x)

Arguments

x

Vector of times to compute the hazard.

G1

List of posterior samples from the BayesPiecewiseHazard function.