Learn R Programming

BayesReversePLLH (version 1.5)

GetALLSurvPEH: Computes the posterior distribution of survival probabilities for a vector x for the Piecewise Exponential Hazard model (PEH)

Description

Computes the posterior distribution of survival probabilities for a vector x for the Piecewise Exponential Hazard model (PEH)

Usage

GetALLSurvPEH(x, G1)

Value

Matrix containing the posterior distribution of survival probabilities S(x)

Arguments

x

Vector of times to compute the posterior mean survival probability.

G1

List of posterior samples from the BayesPiecewiseLinearHazard function.