Learn R Programming

BayesReversePLLH (version 1.5)

GetALLSurvPLLH: Computes posterior distribution of survival probabilities for a vector x for the Piecewise Linear Log Hazard model (PLLH)

Description

Computes posterior distribution of survival probabilities for a vector x for the Piecewise Linear Log Hazard model (PLLH)

Usage

GetALLSurvPLLH(x, G1)

Value

Matrix containing the posterior distribution survival probabilities S(x)

Arguments

x

Vector of times to compute the posterior mean survival probability.

G1

List of posterior samples from the BayesPiecewiseLinearLogHazard function.