Learn R Programming

BayesReversePLLH (version 1.5)

PostMeanHazPiece: Computes the posterior mean hazard values for a vector x for the Piecewise Exponential Hazard model (PEH)

Description

Computes the posterior mean hazard values for a vector x for the Piecewise Exponential Hazard model (PEH)

Usage

PostMeanHazPiece(x, G1)

Value

Vector containing the posterior mean hazard values h(x)

Arguments

x

Vector of times to compute the posterior mean hazard.

G1

List of posterior samples from the BayesPiecewiseHazard function.