Learn R Programming

BayesReversePLLH (version 1.5)

PostMeanSurvPEH: Computes the posterior mean survival probabilities for a vector x for the Piecewise Exponential Hazard model (PEH)

Description

Computes the posterior mean survival probabilities for a vector x for the Piecewise Exponential Hazard model (PEH)

Usage

PostMeanSurvPEH(x, G1)

Value

Vector containing the posterior mean survival probabilities S(x)

Arguments

x

Vector of times to compute the posterior mean survival probability.

G1

List of posterior samples from the BayesPiecewiseLinearHazard function.