Learn R Programming

BayesReversePLLH (version 1.5)

PostMeanSurvPLLH: Computes the posterior mean survival probabilities for a vector x for the Piecewise Linear Log Hazard model (PLLH)

Description

Computes the posterior mean survival probabilities for a vector x for the Piecewise Linear Log Hazard model (PLLH)

Usage

PostMeanSurvPLLH(x, G1)

Value

Vector containing the posterior mean survival probabilities S(x)

Arguments

x

Vector of times to compute the posterior mean survival probability.

G1

List of posterior samples from the BayesPiecewiseLinearLogHazard function.