Computes the posterior distribution of hazard value for a vector x for the Piecewise Linear Log Hazard model (PLLH)
GetALLHazLogSlope(x, G1)Matrix containing the posterior distribution of hazard values h(x)
Vector of times to compute the posterior mean hazard function
List of posterior samples from the BayesPiecewiseLinearLogHazard function.