powered by
Computes the posterior hazard values for a vector x for the Piecewise Exponential Hazard model (PEH)
GetALLHazPiece(x, G1)
Matrix containing the posterior distribution of hazard values h(x)
Vector of times to compute the hazard.
List of posterior samples from the BayesPiecewiseHazard function.