Computes the posterior distribution of survival probabilities for a vector x for the Piecewise Exponential Hazard model (PEH)
GetALLSurvPEH(x, G1)Matrix containing the posterior distribution of survival probabilities S(x)
Vector of times to compute the posterior mean survival probability.
List of posterior samples from the BayesPiecewiseLinearHazard function.