Computes posterior distribution of survival probabilities for a vector x for the Piecewise Linear Log Hazard model (PLLH)
GetALLSurvPLLH(x, G1)Matrix containing the posterior distribution survival probabilities S(x)
Vector of times to compute the posterior mean survival probability.
List of posterior samples from the BayesPiecewiseLinearLogHazard function.