PostMeanHazLogSlope: Computes the posterior mean hazard value for a vector x for the Piecewise Linear Log Hazard model (PLLH)
Description
Computes the posterior mean hazard value for a vector x for the Piecewise Linear Log Hazard model (PLLH)
Usage
PostMeanHazLogSlope(x, G1)
Value
Vector containing the posterior mean hazard values h(x)
Arguments
- x
Vector of times to compute the posterior mean hazard function
- G1
List of posterior samples from the BayesPiecewiseLinearLogHazard function.