powered by
Computes the posterior mean hazard values for a vector x for the Piecewise Exponential Hazard model (PEH)
PostMeanHazPiece(x, G1)
Vector containing the posterior mean hazard values h(x)
Vector of times to compute the posterior mean hazard.
List of posterior samples from the BayesPiecewiseHazard function.