Computes the posterior mean survival probabilities for a vector x for the Piecewise Linear Log Hazard model (PLLH)
PostMeanSurvPLLH(x, G1)Vector containing the posterior mean survival probabilities S(x)
Vector of times to compute the posterior mean survival probability.
List of posterior samples from the BayesPiecewiseLinearLogHazard function.